aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xastro/21cm/get_slice_zfreq.py2
-rwxr-xr-xastro/21cm/make_lightcone.py6
2 files changed, 4 insertions, 4 deletions
diff --git a/astro/21cm/get_slice_zfreq.py b/astro/21cm/get_slice_zfreq.py
index 161b714..5687160 100755
--- a/astro/21cm/get_slice_zfreq.py
+++ b/astro/21cm/get_slice_zfreq.py
@@ -82,7 +82,7 @@ class LightCone:
header["Lside"] = (self.header["Lside"],
self.header.comments["Lside"])
header["Nside"] = (self.header["Nside"],
- self.header.comments["Lside"])
+ self.header.comments["Nside"])
header["REDSHIFT"] = (z, "redshift of this slice")
header["FREQ"] = (freq, "[MHz] observed HI signal frequency")
header["Dc"] = (Dc, "[cMpc] comoving distance")
diff --git a/astro/21cm/make_lightcone.py b/astro/21cm/make_lightcone.py
index 3c86670..75f0d19 100755
--- a/astro/21cm/make_lightcone.py
+++ b/astro/21cm/make_lightcone.py
@@ -49,10 +49,10 @@ unit: K
zmin:
zmax:
dz:
-# Simulation cube side length [Mpc] (required)
+# Simulation cube side length [cMpc] (required)
# (sim_length from SimFast21 configuration file)
Lside:
# Number of cells of the input cubes (required)
# (N_smoothed from SimFast21 configuration file)
Nside:
# Filename pattern of the input coeval cubes
@@ -271,7 +271,7 @@ class LightCone:
header["Dc_max"] = (Dc_max, "[cMpc] comoving distance at zmax")
header["Dc_step"] = (dDc, "[cMpc] comoving distance between slices")
header["Lside"] = (self.configs.Lside, "[cMpc] Simulation side length")
- header["Nside"] = (self.configs.Nside, "Side number of cells")
+ header["Nside"] = (self.configs.Nside, "Number of cells at each side")
header["DATE"] = (datetime.now(timezone.utc).astimezone().isoformat(),
"File creation date")
header.add_history(" ".join(sys.argv))
@@ -49,10 +49,10 @@ unit: K
# (sim_length from SimFast21 configuration file)
Lside:
-# Number of cells of the input cubes (required)
+# Number of cells at each side of the input cubes (required)
# (N_smoothed from SimFast21 configuration file)
Nside: